@@ -1,7 +1,5 @@
 # imports
-import os
 import platform
-import sys
 import urllib
 import urlparse
 import time
@@ -14,12 +12,6 @@ from version import VERSION
 import importer
 json = importer.import_json()
 
-# cStringIO is faster - use where available!
-try:
-  import cStringIO as StringIO
-except ImportError:
-  import StringIO
-
 # use urlfetch as request_lib on google app engine, otherwise use requests
 request_lib = None
 try:
@@ -62,31 +54,39 @@ class Error(Exception):
       pass
 
 def convert_to_easypost_object(response, api_key):
-  types = { 'Address': Address,
-            'ScanForm': ScanForm,
-            'CustomsItem': CustomsItem,
-            'CustomsInfo': CustomsInfo,
-            'Parcel': Parcel,
-            'Shipment': Shipment,
-            'Rate': Rate,
-            'Refund': Refund,
-            'Batch': Batch,
-            'Event': Event,
-            'Tracker': Tracker,
-            'PostageLabel': PostageLabel }
+  types = {
+    'Address': Address,
+    'ScanForm': ScanForm,
+    'CustomsItem': CustomsItem,
+    'CustomsInfo': CustomsInfo,
+    'Parcel': Parcel,
+    'Shipment': Shipment,
+    'Rate': Rate,
+    'Refund': Refund,
+    'Batch': Batch,
+    'Event': Event,
+    'Tracker': Tracker,
+    'Pickup': Pickup,
+    'PickupRate': PickupRate,
+    'PostageLabel': PostageLabel
+  }
 
-  prefixes = { 'adr': Address,
-            'sf': ScanForm,
-            'evt': Event,
-            'cstitem': CustomsItem,
-            'cstinfo': CustomsInfo,
-            'prcl': Parcel,
-            'shp': Shipment,
-            'rate': Rate,
-            'rfnd': Refund,
-            'batch': Batch,
-            'trk': Tracker,
-            'pl': PostageLabel }
+  prefixes = {
+    'adr': Address,
+    'sf': ScanForm,
+    'evt': Event,
+    'cstitem': CustomsItem,
+    'cstinfo': CustomsInfo,
+    'prcl': Parcel,
+    'shp': Shipment,
+    'rate': Rate,
+    'rfnd': Refund,
+    'batch': Batch,
+    'trk': Tracker,
+    'pickup': Pickup,
+    'pickuprate': PickupRate,
+    'pl': PostageLabel
+  }
 
   if isinstance(response, list):
     return [convert_to_easypost_object(i, api_key) for i in response]
@@ -504,11 +504,12 @@ class DeleteResource(Resource):
 # specific resources
 class Address(AllResource, CreateResource):
   @classmethod
-  def create_and_verify(self):
+  def create_and_verify(cls, api_key=None, carrier=None, **params):
     requestor = Requestor(api_key)
     url = "%s/%s" % (cls.class_url(), "create_and_verify")
     wrapped_params = {}
     wrapped_params[cls.class_name()] = params
+    wrapped_params[carrier] = carrier
     response, api_key = requestor.request('post', url, wrapped_params)
 
     response_address = response.get('address', None)
@@ -523,9 +524,9 @@ class Address(AllResource, CreateResource):
     else:
       return convert_to_easypost_object(response, api_key)
 
-  def verify(self):
+  def verify(self, carrier=None):
     requestor = Requestor(self.api_key)
-    url = "%s/%s" % (self.instance_url(), "verify")
+    url = "%s/%s?carrier=%s" % (self.instance_url(), "verify", carrier)
     response, api_key = requestor.request('get', url)
 
     response_address = response.get('address', None)
@@ -673,14 +674,38 @@ class Batch(AllResource, CreateResource):
     self.refresh_from(response, api_key)
     return self
 
+  def create_scan_form(self, **params):
+    requestor = Requestor(self.api_key)
+    url = "%s/%s" % (self.instance_url(), "scan_form")
+    response, api_key = requestor.request('post', url, params)
+    self.refresh_from(response, api_key)
+    return self
+
 class PostageLabel(AllResource, CreateResource):
   pass
 
 class Tracker(AllResource, CreateResource):
   pass
 
+class Pickup(AllResource, CreateResource):
+  def buy(self, **params):
+    requestor = Requestor(self.api_key)
+    url = "%s/%s" % (self.instance_url(), "buy")
+    response, api_key = requestor.request('post', url, params)
+    self.refresh_from(response, api_key)
+    return self
+
+  def cancel(self, **params):
+    requestor = Requestor(self.api_key)
+    url = "%s/%s" % (self.instance_url(), "cancel")
+    response, api_key = requestor.request('post', url, params)
+    self.refresh_from(response, api_key)
+    return self
+
+class PickupRate(Resource):
+  pass
+
 class Event(Resource):
 
   def receive(self, values):
     self.refresh_from(values, None)
-
